@@ -2,10 +2,10 @@ package Devel::Cover::Report::Html_subtle;
 use strict;
 use warnings;
 
-our $VERSION = "0.26";
+our $VERSION = "0.27";
 
-use Devel::Cover::DB 0.26;
-use Devel::Cover::Truth_Table 0.26;
+use Devel::Cover::DB 0.27;
+use Devel::Cover::Truth_Table 0.27;
 
 use Cwd();
 use Template 2.00;
@@ -388,7 +388,7 @@ package Devel::Cover::Report::Html_subtle::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = "0.26";
+our $VERSION = "0.27";
 
 use base "Template::Provider";
 
@@ -406,7 +406,7 @@ sub fetch {
 $Templates{html} = <<'EOT';
 <!--
 
-This file was generated by Devel::Cover Version 0.26
+This file was generated by Devel::Cover Version 0.27
 
 Devel::Cover is copyright 2001-2002, Paul Johnson (pjcj@cpan.org)
 
@@ -733,7 +733,7 @@ Huh?
 
 =head1 VERSION
 
-Version 0.26 - 12th October 2003
+Version 0.27 - 9th November 2003
 
 =head1 LICENCE
 
@@ -781,6 +781,7 @@ code {
 
 table {
 /*	border: solid 1px #000000;*/
+/*      border-collapse: collapse;*/
 }
 td,th {
 	border: solid 1px #cccccc;
